![Homepage](./homepage.png)

# Panqake: Stack Git Branches Without Headache

Panqake is a CLI tool that makes managing dependent pull requests significantly easier by automating the entire git-stacking workflow.

See [introduction](https://panqake.com/introduction) to learn more.

## Installation

```bash
uv tool install panqake
```

### Optional:

- gh: GitHub CLI (needed only for PR creation/management)

For more information, see [here](https://panqake.com/installation)

## Quick Start

[Quickstart](https://panqake.com/quickstart)

## Commands

[Commands reference](https://panqake.com/commands/)

## Contributing

Contributions are welcome! Please feel free to open an issue to discuss your ideas.

## License

MIT
